<xsl:stylesheet xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" version = "1.0" > 
<xsl:output method = "html" /> 


<xsl:template match="/">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
	<xsl:apply-templates />
</html>
</xsl:template>



<xsl:template match="file">
<head>
<title><xsl:value-of select="name" /> - pyDox Documentation</title>
<link rel="stylesheet" type="text/css" href="pydox2xhtml.css" />
</head>
<body>
	<a name="top" />
	<div class="fileHeader" align="right">
	<tt>
	<xsl:value-of select="name" /> 
		<xsl:if test="version != ''">
		- v<xsl:value-of select="version" />
		</xsl:if>
	</tt>
	</div>
	<br />
	<div class="path" align="right">
		<xsl:value-of select="path" />
	</div>
	<br />

	<table border="0" class="quickJump" width="100%">
	<tr>
	<xsl:if test="count(imports/module) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#imports">Imports</a></td>
	</xsl:if>
	<xsl:if test="(count(globals/variable) + count(globals/constants)) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#globals">Globals</a></td>
	</xsl:if>
	<xsl:if test="count(exceptions/class) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#exceptions">Exceptions</a></td>
	</xsl:if>
	<xsl:if test="count(classes/class) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#classes">Classes</a></td>
	</xsl:if>
	<xsl:if test="count(functions/function) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#functions">Functions</a></td>
	</xsl:if>
	<xsl:if test="count(author/descendant::*) &gt; 0">
	<td align="center" class="quickJump"><a class="quickJump" href="#author">Author</a></td>
	</xsl:if>
	</tr>
	</table>

	<div class="sectionHeader">
	File Information
	</div>

	<xsl:apply-templates select="comment" />
	<xsl:apply-templates select="imports" />
	<xsl:apply-templates select="globals" />
	<xsl:apply-templates select="exceptions" />
	<xsl:apply-templates select="classes" />
	<xsl:apply-templates select="functions" />
	<xsl:apply-templates select="author" />

	<br />
	<hr width="80%" align="right" />
	<div class="credit" align="right">
	Documentation created by pyDox v0.5a - Seung Chan Lim [ dev@djslim.com ]
	</div>
</body>
</xsl:template>



<xsl:template match="author">
<xsl:if test="count(descendant::*) &gt; 0">
	<a name="author" />
	<div class="section">
	<div class="sectionHeader">Author</div>
	<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
	<div class="sectionBody">
		<a>
		<xsl:if test="email!=''">
			<xsl:attribute name="href">
				mailto:<xsl:value-of select="email" />
			</xsl:attribute>
				<xsl:value-of select="name" />
		</xsl:if>
		</a>
		
		<xsl:if test="homepage!=''">
		&#160;[ <a target="_new">
			<xsl:attribute name="href">
				<xsl:value-of select="homepage" />
			</xsl:attribute>
		homepage</a> ]
		</xsl:if>
	</div>
	</div>
	</xsl:if>
</xsl:template>




<xsl:template match="name">
	<xsl:value-of select="." />
</xsl:template>




<xsl:template match="comment">
	<pre><code><xsl:value-of select="text()" /></code></pre>
</xsl:template>



<xsl:template match="imports">
	<xsl:if test="count(module) &gt; 0">
		<a name="imports" />
		<div class="section">
		<div class="sectionHeader">Imports</div>
		<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
		<div class="sectionBody">
			<xsl:apply-templates />
		</div>
		</div>
	</xsl:if>
</xsl:template>



<xsl:template match="globals">
	<xsl:if test="(count(variable) + count(constants)) &gt; 0">
		<a name="globals" />
		<div class="section">
		<div class="sectionHeader">Globals</div>
		<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
		<br />
		<div class="sectionBody">
			<xsl:apply-templates select="variable" />
	
			<xsl:apply-templates select="constants" />
		</div>
 		</div>
	</xsl:if>
</xsl:template>



<xsl:template match="exceptions">
	<xsl:if test="count(class) &gt; 0">
		<a name="exceptions" />
		<div class="section">
		<div class="sectionHeader">Exceptions</div>
		<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
		<div class="sectionBody">
			<xsl:apply-templates />
		</div>
		</div>
	</xsl:if>
</xsl:template>



<xsl:template match="classes">
	<xsl:if test="count(class) &gt; 0">
		<a name="classes" />
		<div class="section">
		<div class="sectionHeader">Classes</div>
		<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
		<div class="sectionBody">
			<xsl:apply-templates />
		</div>
		</div>
	</xsl:if>
</xsl:template>



<xsl:template match="functions">
	<xsl:if test="count(function) &gt; 0">
		<a name="functions" />
		<div class="section">
		<div class="sectionHeader">Functions</div>
		<div align="right" class="topAnchor"><a href="#top">Back to Top</a></div>
		<div class="sectionBody">
			<xsl:apply-templates />
		</div>
		</div>
	</xsl:if>
</xsl:template>





<xsl:template match="variable">
<div class="variable">
<strong><xsl:apply-templates select="name" /></strong>
	
	<xsl:if test="val!=''">
	&#160;<em>&lt;type: <strong><xsl:value-of select="val/@type" /></strong>&gt;</em>
	</xsl:if>

<div class="subSection">
<xsl:apply-templates select="val" />
</div>
</div>
<br />
</xsl:template>



<xsl:template match="constants">
<div class="constants">
<strong><xsl:apply-templates select="name" /></strong>
	
	<xsl:if test="val!=''">
	&#160;<em>&lt;type: <strong><xsl:value-of select="val/@type" /></strong>&gt;</em>
	</xsl:if>

<div class="subSection">
<xsl:apply-templates select="val" />
</div>
</div>
<br />
</xsl:template>





<xsl:template match="module">
	<div class="module"><xsl:value-of select="name" /></div>
</xsl:template>





<xsl:template match="val">
	<xsl:value-of select="." />
</xsl:template>




<xsl:template match="class">
	<div class="section">
	<div class="classHeader">
	<xsl:value-of select="name" />
	</div>
	<div class="subSection">
	<xsl:apply-templates select="bases" />
	<xsl:apply-templates select="comment" />

	<xsl:for-each select="locals">
		<xsl:apply-templates select="var" />
	</xsl:for-each>

	<xsl:apply-templates select="constructor" />
	<xsl:apply-templates select="destructor" />
	<xsl:apply-templates select="operators" />
	<xsl:apply-templates select="methods" />

	</div>
	</div>
	<hr width="200" align="right" />
</xsl:template>




<xsl:template match="constructor">
	<xsl:if test="count(function) &gt; 0">
		<div class="subSectionHeader">Constructor</div>
		<xsl:apply-templates select="function" />
	</xsl:if>
</xsl:template>



<xsl:template match="destructor">
	<xsl:if test="count(function) &gt; 0">
		<div class="subSectionHeader">Destructor</div>
		<xsl:apply-templates select="function" />
	</xsl:if>
</xsl:template>


<xsl:template match="operators">
	<xsl:if test="count(function) &gt; 0">
		<div class="subSectionHeader">Operators</div>
		<xsl:apply-templates select="function" />
	</xsl:if>
</xsl:template>


<xsl:template match="methods">
	<xsl:for-each select="public">
		<xsl:if test="count(function) &gt; 0">
			<xsl:if test="position()=1">
				<div class="subSectionHeader">Public Methods</div>
			</xsl:if>
			<xsl:apply-templates select="function" />
		</xsl:if>
	</xsl:for-each>

	<xsl:for-each select="protected">
		<xsl:if test="count(function) &gt; 0">
			<xsl:if test="position()=1">
				<div class="subSectionHeader">Protected Methods</div>
			</xsl:if>
			<xsl:apply-templates select="function" />
		</xsl:if>
	</xsl:for-each>

	<xsl:for-each select="private">
		<xsl:if test="count(function) &gt; 0">
			<xsl:if test="position()=1">
				<div class="subSectionHeader">Private Methods</div>
			</xsl:if>
			<xsl:apply-templates select="function" />
		</xsl:if>
	</xsl:for-each>
</xsl:template>



<xsl:template match="bases">
	<xsl:if test="count(class) &gt; 0">
		<div>
		<strong>Base classes:</strong><br />
		<em>
		<xsl:for-each select="class">
			<xsl:if test="package != ''"><xsl:value-of select="package" />.</xsl:if>
			<xsl:value-of select="name" /><br />
		</xsl:for-each>
		</em>
		</div>
	</xsl:if>
</xsl:template>


<xsl:template match="arguments">
		<table border="0">
		<xsl:for-each select="argument">
			<tr><td>

			<xsl:if test="../@defaultIndex &lt;= ../@argumentCount">
			<xsl:attribute name="class">
				<xsl:if test="position() &gt;= ../@defaultIndex">
					<xsl:if test="position() &lt;= ../@argumentCount">
						defaultArg
					</xsl:if>
				</xsl:if>
			</xsl:attribute>
			</xsl:if>

			<xsl:if test="@type='list'">*</xsl:if>
			<xsl:if test="@type='keyword'">**</xsl:if>

			<xsl:if test="../@defaultIndex = ../@argumentCount">
				<xsl:if test="../@argumentCount = 1">
				<em> [ </em>
				</xsl:if>
			</xsl:if>

			<xsl:value-of select="name" />
			<xsl:if test="val!=''"> = <xsl:value-of select="val" /></xsl:if>


			<xsl:if test="../@defaultIndex &lt;= ../@argumentCount">
			<xsl:if test="(position()+1)=../@defaultIndex"> <em> [</em> </xsl:if>
			<xsl:if test="position()=../@argumentCount"> ] </xsl:if>
			</xsl:if>

			<xsl:if test="position()!=last()"><span class="plain">, </span></xsl:if></td></tr>
		</xsl:for-each>

		</table>
</xsl:template>




<xsl:template match="function">
	<div class="section">
	<!--xsl:attribute name="rowspan">
		<xsl:value-of select="count(descendant::var)" />
	</xsl:attribute-->
	<table border="0">
	<tr>
	<td valign="top" class="functionHeader">
	<xsl:value-of select="name" />(
	</td>
	<td>
	<xsl:apply-templates select="arguments" />
	</td>
	<td valign="bottom" class="functionHeader">
	)
	</td></tr></table>
	<div class="subSection">
	<xsl:apply-templates select="comment" />
	</div>
	</div>
</xsl:template>





</xsl:stylesheet>